==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/InputChangeEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { InputChangeEventArgsDescription } from "./InputChangeEventArgsDescription";
/**
 * @hidden
 */
var InputChangeEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(InputChangeEventArgsDescriptionMetadata, _super);
    function InputChangeEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    InputChangeEventArgsDescriptionMetadata.b = function (a) {
        if (InputChangeEventArgsDescriptionMetadata.a == null) {
            InputChangeEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            InputChangeEventArgsDescriptionMetadata.c(InputChangeEventArgsDescriptionMetadata.a);
        }
        if (a.j(InputChangeEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(InputChangeEventArgsDescriptionMetadata.a);
    };
    InputChangeEventArgsDescriptionMetadata.c = function (a) {
        a.item("Value", "String");
        a.item("IsCompositionInProgress", "Boolean");
    };
    InputChangeEventArgsDescriptionMetadata.d = function (a) {
        InputChangeEventArgsDescriptionMetadata.b(a);
        a.aa("InputChangeEventArgs", function () { return new InputChangeEventArgsDescription(); });
        a.z("InputChangeEventArgs", InputChangeEventArgsDescriptionMetadata.a);
    };
    InputChangeEventArgsDescriptionMetadata.$t = markType(InputChangeEventArgsDescriptionMetadata, 'InputChangeEventArgsDescriptionMetadata');
    InputChangeEventArgsDescriptionMetadata.a = null;
    return InputChangeEventArgsDescriptionMetadata;
}(Base));
export { InputChangeEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/InputChangeEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { InputChangeEventArgsDescription } from "./InputChangeEventArgsDescription";
/**
 * @hidden
 */
var InputChangeEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(InputChangeEventArgsDescriptionMetadata, _super);
    function InputChangeEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    InputChangeEventArgsDescriptionMetadata.b = function (a) {
        if (InputChangeEventArgsDescriptionMetadata.a == null) {
            InputChangeEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            InputChangeEventArgsDescriptionMetadata.c(InputChangeEventArgsDescriptionMetadata.a);
        }
        if (a.k(InputChangeEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(InputChangeEventArgsDescriptionMetadata.a);
    };
    InputChangeEventArgsDescriptionMetadata.c = function (a) {
        a.item("Value", "String");
        a.item("IsCompositionInProgress", "Boolean");
    };
    InputChangeEventArgsDescriptionMetadata.d = function (a) {
        InputChangeEventArgsDescriptionMetadata.b(a);
        a.ac("InputChangeEventArgs", function () { return new InputChangeEventArgsDescription(); });
        a.ab("InputChangeEventArgs", InputChangeEventArgsDescriptionMetadata.a);
    };
    InputChangeEventArgsDescriptionMetadata.$t = markType(InputChangeEventArgsDescriptionMetadata, 'InputChangeEventArgsDescriptionMetadata');
    InputChangeEventArgsDescriptionMetadata.a = null;
    return InputChangeEventArgsDescriptionMetadata;
}(Base));
export { InputChangeEventArgsDescriptionMetadata };
